@@ -32,6 +32,7 @@ from .newvideo import Video
 from .orientationlayout import OrientationLayout
 from .threadcall import HttpClient
 from .register import *
+from .script import Script, set_script_env
 
 class WidgetNotFoundById(Exception):
 	def __init__(self, id):
@@ -108,6 +109,11 @@ class Blocks(EventDispatcher):
 		self.register_event_type('on_built')
 		self.register_event_type('on_failed')
 		self.env = GlobalEnv()
+		config = getConfig()
+		if config.script_root:
+			self.script = Script(config.script_root)
+		else:
+			self.script = Script(config.workdir)
 
 	def set(self, k:str, v):
 		self.env[k] = v
@@ -157,11 +163,7 @@ class Blocks(EventDispatcher):
 				return None
 
 		if url.startswith('file://'):
-			filename = url[7:]
-			with codecs.open(filename,'r','utf-8') as f:
-				b = f.read()
-				dic = json.loads(b)
-				return dic
+			return self.script.dispatch(url, **params)
 		elif url.startswith('http://') or url.startswith('https://'):
 			try:
 				hc = HttpClient()
@@ -240,7 +242,6 @@ class Blocks(EventDispatcher):
 		return obj
 
 	def w_build(self,desc) -> Widget:
-		# print('w_build(),desc=',desc)
 		widgetClass = desc.get('widgettype',None)
 		if not widgetClass:
 			Logger.info("Block: w_build(), desc invalid", desc)
@@ -285,7 +286,7 @@ class Blocks(EventDispatcher):
 			if isinstance(v,dict) and v.get('widgettype'):
 				b = Blocks()
 				v = self.valueExpr(v, localnamespace={'self':widget})
-				w = b.w_build(v)
+				w = b.widgetBuild(v)
 				if hasattr(widget,k):
 					aw = getattr(widget,k)
 					if isinstance(aw,Layout):
@@ -785,6 +786,36 @@ class Blocks(EventDispatcher):
 	def on_failed(self,e=None):
 		return
 
+	def buildKlass(self, desc):
+		"""
+		desc = {
+			"classname":"MyClass",
+			"base":["Box", "WidgetReady"],
+			"properties":[
+				{
+					"name":"aaa",
+					"type":"str",
+					"default":1
+				}
+			]
+			"subwidgets":[
+			],
+			
+		"""
+		codes = """
+{% for b in bases %}
+{{b}} = Factory.{{b}}
+{% endfor %}
+
+class {{ classname }}({% for b in bases -%}{{b}}{% endfor %})
+{% for p in properties %}
+	{{p.name}} {{p.type}}({{p.default}})
+{% endfor %}
+	def __init__(self, **kw):
+		super({{classname}}, self).__init__(**kw)
+
+"""
+
 Factory.register('Blocks',Blocks)
 Factory.register('Video',Video)
 Factory.register('OrientationLayout', OrientationLayout)
